package com.k2.tornado.layers;

import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.game.*;

public interface BaseLayer
{
	public static final int SPRITESTATE_IDLE = 0;
	public static final int SPRITESTATE_MOVING_LEFT = 1;
	public static final int SPRITESTATE_MOVING_RIGHT = 2;
	public static final int SPRITESTATE_LEAPING = 4;
	public static final int SPRITESTATE_FALLING = 8;
	public static final int SPRITESTATE_WALKING = 16;
	public static final int SPRITESTATE_FLYING = 32; // currently ignored
	public static final int SPRITESTATE_DYING = 64;

	/** returns the the bounds value of the tile at the given position */
	public int getBounds(int column, int row);
	/** returns the the map code of the tile at the given position */
	public int getMapCode(int column, int row);
	/** checks for collissions */
	public boolean checkCollission(Sprite sprite, int state);
	/** attempts to move the layer horizontally and returns false if moving failed*/
	public boolean hMove(int delta);
	/** attempts to move the layer verticaly and returns false if moving failed*/
	public boolean vMove(int delta);
	/** sets the display dimensions*/
	public void setDisplaySize(int width, int height);
	/** handles animated tiles*/
	public void animate();
	/** returns the last MapCode that the avatar collided with*/
	public int getLastMapCode();
	/** places the avatar at the in-point of the map*/
	public void setAvatarPosition(Sprite avatar);
	/** paints the layer */
	public void paint(Graphics g);
	/** moves the layer*/
	public void move(int dx, int dy);
	/** returns the x-pos*/
	public int getX();
	/** returns the y-pos*/
	public int getY();
}