package com.k2.tornado.layers;

public class TileSequence
{
	/** the tiles for this sequence*/
	private int[] m_tiles;
	/** number of frames per tile (must be at least 1 for each tile)*/
	private int[] m_frames;
	/** the index within the tile-array*/
	private int m_index = 0;
	/** counts the frames thus determines when m_index is to be increased*/
	private int m_frameCount = 0;
	/** internal sequence number*/
	private int m_sequenceNumber;
	/** number of different tiles in this sequence*/
	private int m_sequenceLength;

    public TileSequence(int sequenceNumber, int sequenceLength)
    {
		m_sequenceNumber = sequenceNumber;
		// the sequence number must be positive
		if (m_sequenceNumber < 0)
			m_sequenceNumber *= -1;

		m_sequenceLength = sequenceLength;
		/** create the 2 arrays that will hold frame numbers and tile numbers*/
		m_tiles = new int[sequenceLength];
		m_frames = new int[sequenceLength];
    }

	public void addTile(int index, int tile, int frames)
	{
		// can we add this tile?
		if (index < m_sequenceLength)
		{
			// yer
			m_tiles[index] = tile;
			// make sure frames is at least one
			frames = frames < 1 ? 1 : frames;
			m_frames[index] = frames;
		}//if
	}

	public void reset()
	{
		// reset the index
		m_index = 0;
		// get the framecount for the first tile
		m_frameCount = m_frames[0];
	}

	public int getNextTile()
	{
		// get the tile
		int tile = m_tiles[m_index];

		// next frame
		m_frameCount--;

		// can we switch to the next tile index?
		if (m_frameCount == 0)
		{
			// yer
			m_index = m_index < m_sequenceLength-1 ? m_index+1 : 0;
			m_frameCount = m_frames[m_index];
		}//if

		return tile;
	}

	public int getSequenceNumber()
	{
		return m_sequenceNumber;
	}
}