package com.k2.tornado.midlet;

import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

/**
 * <p>Title: Tornado</p>
 * <p>Description: A cat's adventure in a land of weirdos</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: K-Square</p>
 * @author Steffen Kluge
 * @version 0.1
 */

public class TornadoCore extends MIDlet implements CommandListener
{
	/**
	 * All commands are handled by the midlet. Since there are just a
	 * few and some are shared by screens it's seems alright to do so.
	 * Besides it saves the damned static instance attribute generated
	 * by JBuilder...
	 * The priorities are adapted from the WTK20 push puzzle example.
	 */
	// the back command always goes back the the opening screen
	public Command backCommand = new Command("Back", Command.BACK, 1);
	// exit closes the application
	private Command exitCommand = new Command("Exit", Command.EXIT, 60);
	// scores shows the highscores
	private Command scoresCommand = new Command("Scores", Command.SCREEN, 26);
	// ok confirms some input
	private Command okCommand = new Command("Ok", Command.OK, 30);
	// settings shows the settings form
	private Command settingsCommand = new Command("Settings", Command.SCREEN, 30);
	// play starts the game
	private Command playCommand = new Command("Play", Command.SCREEN, 24);
	// intro shows sort of an about-animation
	private Command introCommand = new Command("Intro", Command.SCREEN, 25);

	/**
	 * The various screens represent the game modes. Two screens are in fullscreen
	 * mode: m_gameScreen and m_introScreen. The rest run in "windowed" mode.
	 */
	private OpeningScreen m_opener = new OpeningScreen();
	private GameScreen m_game = new GameScreen(this);
	private HighscoreScreen m_scores = new HighscoreScreen();
	private SettingsScreen m_settings = new SettingsScreen();

	// the midlet's display
	private Display m_display;

	/** Constructor */
	public TornadoCore()
	{
		// get the display
		m_display = Display.getDisplay(this);

		// assign the command listener to the screens
		m_opener.setCommandListener(this);
		// m_game.setCommandListener(this);
		m_scores.setCommandListener(this);
		m_settings.setCommandListener(this);

		// assign the commands to our screens
		m_opener.addCommand(playCommand);
		m_opener.addCommand(introCommand);
		m_opener.addCommand(scoresCommand);
		m_opener.addCommand(settingsCommand);
		m_opener.addCommand(exitCommand);
		// m_game.addCommand(backCommand);
		m_scores.addCommand(backCommand);
		m_settings.addCommand(backCommand);
	}

	/** Main method */
	public void startApp()
	{
		// we'll start with the opening screen - in windowed mode
		m_display.setCurrent(m_opener);
	}

	/** Handle pausing the MIDlet */
	public void pauseApp()
	{
	}

	/** Handle destroying the MIDlet */
	public void destroyApp(boolean unconditional)
	{
		// stop any threads that we might have started before and that could be still running
		m_game.stopLoop();

		// restore the display
		m_display.setCurrent((Displayable)null);
		/**
		 * @todo clean up screens
		 */
		// notify everybody who's interested that we've destroyed the midlet
		this.notifyDestroyed();
	}

	/**
	 * This method handles all menu commands
	 * @param c the command
	 * @param d the displayable that sent the command
	 */
	public void commandAction(Command c, Displayable d)
	{
		if (c == exitCommand) {
			// exit the application
			destroyApp(false);
		}
		else if (c == backCommand) {
			// stop the game thread if it was active
			if (d == m_game)
			{
				m_game.stopLoop();
			}//if
			// we'll return to the opening screen
			m_display.setCurrent(m_opener);
		}
		else if (c == playCommand)
		{
			// show the game screen
			m_display.setCurrent(m_game);
			// start the game loop
			m_game.startLoop();
		}
		else if (c == scoresCommand)
		{
			// show the highscore list
			m_display.setCurrent(m_scores);
		}
		else if (c == settingsCommand)
		{
			// show the settings dialog
			m_display.setCurrent(m_settings);
		}

	}

}
